/**************************************************************
 * Structured Markov Chains Solver       [  SMCSolver  ]      *
 * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
 * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
 * Dipartimento di Matematica "Leonida Tonelli"               *
 * Largo Pontecorvo 5                                         *
 * 56127 Pisa                                                 *
 * Italy                                                      *
 * Version 2.1 - June  2009                                   *
 **************************************************************
 *
 *  help.h  - about and  help
 *
 */

/* prototypes help.c */
void create_window_about(void);   
void create_window_help(void);
void on_help_title1_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title2_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title3_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title4_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title5_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title6_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title7_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title8_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title9_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_title10_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_biblio_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_credits_clicked  (GtkButton       *button, gpointer         user_data);
void on_help_thanks_clicked  (GtkButton       *button, gpointer         user_data);

/* prototypes callbacks.c */
void on_help_closebutton_clicked   (GtkButton  *, gpointer );
void on_help_destroy_activate   (GtkWidget *, gpointer );
void on_about_closebutton_clicked  (GtkButton   *, gpointer );
void on_about_destroy_activate   (GtkWidget *, gpointer );

/* globals help.c */
GtkTextBuffer *bufferm;

/*globals main.c */
int is_smallscr;
/*********************************************/
